echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	#[[ $(command -v btmon) == "" ]] && echo "Installing UASM" && extension --install uasm && echo "Finished UASM"
	echo
fi

if [ $BUILD_ALL == "false" ] && [[ $(7z | cut -d " " -f 2 | sed 1d | sed 2,70d) != "25.01" ]]; then
	echo "7zip" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "7zip" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
